@@ -13,32 +13,55 @@
 #
 ##############################################################################
 
-__docformat__ = "restructuredtext"
 
 # import standard packages
 
 # import Zope3 interfaces
+from z3c.form import field
 
 # import local interfaces
+from ztfy.scheduler.interfaces import IZODBPackingTaskInfo
 
 # import Zope3 packages
 
 # import local packages
-from ztfy.skin.menu import MenuItem
 from ztfy.scheduler.browser.task import BaseTaskAddForm
 from ztfy.scheduler.zodb import ZODBPackingTask
+from ztfy.skin.form import DialogEditForm
+from ztfy.skin.menu import JsMenuItem
 
 from ztfy.scheduler import _
 
 
-class ZODBPackingTaskAddFormMenu(MenuItem):
+class ZODBPackingTaskAddFormMenu(JsMenuItem):
     """ZODB packing task add form menu"""
 
-    _title = _(" :: Add ZODB packing task...")
+    title = _(" :: Add ZODB packing task...")
 
 
 class ZODBPackingTaskAddForm(BaseTaskAddForm):
     """ZODB packing task add form"""
 
-    def create(self, data):
-        return ZODBPackingTask()
+    task_factory = ZODBPackingTask
+
+
+class ZODBPackingTaskEditFormMenu(JsMenuItem):
+    """ZZODB packing task edit form menu"""
+
+    title = _(" :: Packer properties...")
+
+
+class ZODBPackingTaskEditForm(DialogEditForm):
+    """ZODB packer task edit form"""
+
+    legend = _("Properties of ZEO packed database")
+
+    fields = field.Fields(IZODBPackingTaskInfo)
+    autocomplete = 'off'
+
+    def applyChanges(self, data):
+        result = super(ZODBPackingTaskEditForm, self).applyChanges(data)
+        if result:
+            self.context.resetConnection()
+            self.context.reset()
+        return result
